==> miniorange_saml-7.x-2.71.tar.gz: miniorange_saml/includes/miniorange_saml_support.php <==
<?php
/**
 * @file
 * Contains miniOrange Support class.
 */

/**
 * @file
 * This class represents support information for customer.
 */
class MiniorangeSamlSupport {
	public $email;
	public $phone;
	public $query;
	/**
     * Constructor.
     */
	public function __construct($email, $phone, $query,$plan='') {
      $this->email = $email;
      $this->phone = $phone;
      $this->query = $query;
      $this->plan  = $plan;
	}

	/**
	 * Send support query.
	 */
	public function sendSupportQuery() {
    if ($this->plan == 'Trial Request') {
      $this->query = '[Drupal ' . VERSION . ' SAML SP ' . $this->plan . ' | ' .system_get_info('module', 'miniorange_saml')['version']. ' | ' . phpversion() . ' ] ' . $this->query;
      $this->query = 'Demo required for - ' . $this->query;
      $fields = array (
        'company' => $_SERVER ['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
      );
    }
    else {
      $this->query = '[Drupal-7 SAML SP Free] :' . $this->query;
      $fields = array(
        'company' => $_SERVER ['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
        'subject' => "Drupal-7 SAML SP Free Query",
      );
    }
    $url = MiniorangeSAMLConstants::BASE_URL . '/moas/rest/customer/contact-us';
    $customer = new MiniorangeSAMLCustomer(null, null,null,null);
    $response = $customer->callService($url, $fields, true);
    return $response;
	}
}

==> miniorange_saml-7.x-2.72.tar.gz: miniorange_saml/includes/miniorange_saml_support.php <==
<?php
/**
 * @file
 * Contains miniOrange Support class.
 */

/**
 * @file
 * This class represents support information for customer.
 */
class MiniorangeSamlSupport {
	public $email;
	public $phone;
	public $query;
  private $plan;
  /**
     * Constructor.
     */
	public function __construct($email, $phone, $query,$plan='') {
      $this->email = $email;
      $this->phone = $phone;
      $this->query = $query;
      $this->plan  = $plan;
	}

	/**
	 * Send support query.
	 */
	public function sendSupportQuery() {
    $drupalCore = VERSION;
    $moduleInfo = system_get_info('module', 'miniorange_saml');
    $moduleVersion =  $moduleInfo['version'];
    $phpversion = phpversion();

    if ($this->plan == 'Trial Request') {
      $this->query = "[Drupal $drupalCore SAML SP $this->plan | $moduleVersion | $phpversion ] $this->query";
      $this->query = 'Demo required for - ' . $this->query;
      $fields = array (
        'company' => $_SERVER['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
      );
    }
    else {
      $query = "[Drupal $drupalCore SAML SP | $moduleVersion | PHP $phpversion] $this->query";

      $fields = array(
        'company' => $_SERVER ['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $query,

      );
    }
    $url = MiniorangeSAMLConstants::BASE_URL . '/moas/rest/customer/contact-us';
    $customer = new MiniorangeSAMLCustomer(null, null,null,null);
    $response = $customer->callService($url, $fields, true);
    return $response;
	}
}
